# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_apigateway.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_apigateway.proto\x12\x1aoak9.tython.aws.apigateway\x1a\x13shared/shared.proto\"`\n\x07\x41\x63\x63ount\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63loud_watch_role_arn\x18\x02 \x01(\t\"\xd6\x06\n\nApiGateway\x12\x34\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32#.oak9.tython.aws.apigateway.Account\x12\x33\n\x07\x61pi_key\x18\x02 \x03(\x0b\x32\".oak9.tython.aws.apigateway.ApiKey\x12:\n\nauthorizer\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.apigateway.Authorizer\x12\x46\n\x11\x62\x61se_path_mapping\x18\x04 \x01(\x0b\x32+.oak9.tython.aws.apigateway.BasePathMapping\x12:\n\ndeployment\x18\x05 \x01(\x0b\x32&.oak9.tython.aws.apigateway.Deployment\x12;\n\x0b\x64omain_name\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.apigateway.DomainName\x12\x45\n\x10gateway_response\x18\x07 \x03(\x0b\x32+.oak9.tython.aws.apigateway.GatewayResponse\x12\x32\n\x06method\x18\x08 \x03(\x0b\x32\".oak9.tython.aws.apigateway.Method\x12G\n\x11request_validator\x18\t \x01(\x0b\x32,.oak9.tython.aws.apigateway.RequestValidator\x12\x36\n\x08resource\x18\n \x03(\x0b\x32$.oak9.tython.aws.apigateway.Resource\x12\x35\n\x08rest_api\x18\x0b \x01(\x0b\x32#.oak9.tython.aws.apigateway.RestApi\x12\x30\n\x05stage\x18\x0c \x03(\x0b\x32!.oak9.tython.aws.apigateway.Stage\x12\x39\n\nusage_plan\x18\r \x01(\x0b\x32%.oak9.tython.aws.apigateway.UsagePlan\x12@\n\x0eusage_plan_key\x18\x0e \x01(\x0b\x32(.oak9.tython.aws.apigateway.UsagePlanKey\"r\n\x0e\x41piKeyStageKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0brest_api_id\x18\x02 \x01(\t\x12\x12\n\nstage_name\x18\x03 \x01(\t\"\xe0\x02\n\x06\x41piKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63ustomer_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x1c\n\x14generate_distinct_id\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12>\n\nstage_keys\x18\x07 \x03(\x0b\x32*.oak9.tython.aws.apigateway.ApiKeyStageKey\x12:\n\x04tags\x18\x08 \x03(\x0b\x32,.oak9.tython.aws.apigateway.ApiKey.TagsEntry\x12\r\n\x05value\x18\t \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc3\x02\n\nAuthorizer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tauth_type\x18\x02 \x01(\t\x12\x1e\n\x16\x61uthorizer_credentials\x18\x03 \x01(\t\x12(\n authorizer_result_ttl_in_seconds\x18\x04 \x01(\x05\x12\x16\n\x0e\x61uthorizer_uri\x18\x05 \x01(\t\x12\x17\n\x0fidentity_source\x18\x06 \x01(\t\x12&\n\x1eidentity_validation_expression\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x15\n\rprovider_arns\x18\t \x03(\t\x12\x13\n\x0brest_api_id\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\"\x96\x01\n\x0f\x42\x61sePathMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tbase_path\x18\x02 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\x12\r\n\x05stage\x18\x05 \x01(\t\"\xd5\x01\n\x11\x43lientCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x45\n\x04tags\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.apigateway.ClientCertificate.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x02\n\"DeploymentDeploymentCanarySettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fpercent_traffic\x18\x02 \x01(\x01\x12|\n\x18stage_variable_overrides\x18\x03 \x03(\x0b\x32Z.oak9.tython.aws.apigateway.DeploymentDeploymentCanarySettings.StageVariableOverridesEntry\x12\x17\n\x0fuse_stage_cache\x18\x04 \x01(\x08\x1a=\n\x1bStageVariableOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1a\x44\x65ploymentAccessLogSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xb6\x02\n\x17\x44\x65ploymentCanarySetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fpercent_traffic\x18\x02 \x01(\x01\x12q\n\x18stage_variable_overrides\x18\x03 \x03(\x0b\x32O.oak9.tython.aws.apigateway.DeploymentCanarySetting.StageVariableOverridesEntry\x12\x17\n\x0fuse_stage_cache\x18\x04 \x01(\x08\x1a=\n\x1bStageVariableOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x02\n\x17\x44\x65ploymentMethodSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63\x61\x63he_data_encrypted\x18\x02 \x01(\x08\x12\x1c\n\x14\x63\x61\x63he_ttl_in_seconds\x18\x03 \x01(\x05\x12\x17\n\x0f\x63\x61\x63hing_enabled\x18\x04 \x01(\x08\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\x05 \x01(\x08\x12\x13\n\x0bhttp_method\x18\x06 \x01(\t\x12\x15\n\rlogging_level\x18\x07 \x01(\t\x12\x17\n\x0fmetrics_enabled\x18\x08 \x01(\x08\x12\x15\n\rresource_path\x18\t \x01(\t\x12\x1e\n\x16throttling_burst_limit\x18\n \x01(\x05\x12\x1d\n\x15throttling_rate_limit\x18\x0b \x01(\x01\"\xd4\x07\n\x1a\x44\x65ploymentStageDescription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x12\x61\x63\x63\x65ss_log_setting\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.apigateway.DeploymentAccessLogSetting\x12\x1d\n\x15\x63\x61\x63he_cluster_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12\x63\x61\x63he_cluster_size\x18\x04 \x01(\t\x12\x1c\n\x14\x63\x61\x63he_data_encrypted\x18\x05 \x01(\x08\x12\x1c\n\x14\x63\x61\x63he_ttl_in_seconds\x18\x06 \x01(\x05\x12\x17\n\x0f\x63\x61\x63hing_enabled\x18\x07 \x01(\x08\x12K\n\x0e\x63\x61nary_setting\x18\x08 \x01(\x0b\x32\x33.oak9.tython.aws.apigateway.DeploymentCanarySetting\x12\x1d\n\x15\x63lient_certificate_id\x18\t \x01(\t\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\n \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12\x1d\n\x15\x64ocumentation_version\x18\x0c \x01(\t\x12\x15\n\rlogging_level\x18\r \x01(\t\x12L\n\x0fmethod_settings\x18\x0e \x03(\x0b\x32\x33.oak9.tython.aws.apigateway.DeploymentMethodSetting\x12\x17\n\x0fmetrics_enabled\x18\x0f \x01(\x08\x12N\n\x04tags\x18\x10 \x03(\x0b\x32@.oak9.tython.aws.apigateway.DeploymentStageDescription.TagsEntry\x12\x1e\n\x16throttling_burst_limit\x18\x11 \x01(\x05\x12\x1d\n\x15throttling_rate_limit\x18\x12 \x01(\x01\x12\x17\n\x0ftracing_enabled\x18\x13 \x01(\x08\x12X\n\tvariables\x18\x14 \x03(\x0b\x32\x45.oak9.tython.aws.apigateway.DeploymentStageDescription.VariablesEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xba\x02\n\nDeployment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x1a\x64\x65ployment_canary_settings\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.apigateway.DeploymentDeploymentCanarySettings\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\x12Q\n\x11stage_description\x18\x05 \x01(\x0b\x32\x36.oak9.tython.aws.apigateway.DeploymentStageDescription\x12\x12\n\nstage_name\x18\x06 \x01(\t\"\x95\x01\n\x19\x44ocumentationPartLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x13\n\x0bstatus_code\x18\x05 \x01(\t\"\xbe\x01\n\x11\x44ocumentationPart\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x08location\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.apigateway.DocumentationPartLocation\x12\x12\n\nproperties\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\"\x98\x01\n\x14\x44ocumentationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1d\n\x15\x64ocumentation_version\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\"i\n\x1f\x44omainNameEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05types\x18\x02 \x03(\t\"\x90\x01\n!DomainNameMutualTlsAuthentication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0etruststore_uri\x18\x02 \x01(\t\x12\x1a\n\x12truststore_version\x18\x03 \x01(\t\"\xda\x03\n\nDomainName\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12[\n\x16\x65ndpoint_configuration\x18\x03 \x01(\x0b\x32;.oak9.tython.aws.apigateway.DomainNameEndpointConfiguration\x12`\n\x19mutual_tls_authentication\x18\x04 \x01(\x0b\x32=.oak9.tython.aws.apigateway.DomainNameMutualTlsAuthentication\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x05 \x01(\t\x12 \n\x18regional_certificate_arn\x18\x06 \x01(\t\x12\x17\n\x0fsecurity_policy\x18\x07 \x01(\t\x12>\n\x04tags\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.apigateway.DomainName.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x03\n\x0fGatewayResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x13response_parameters\x18\x02 \x03(\x0b\x32\x43.oak9.tython.aws.apigateway.GatewayResponse.ResponseParametersEntry\x12^\n\x12response_templates\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.apigateway.GatewayResponse.ResponseTemplatesEntry\x12\x15\n\rresponse_type\x18\x04 \x01(\t\x12\x13\n\x0brest_api_id\x18\x05 \x01(\t\x12\x13\n\x0bstatus_code\x18\x06 \x01(\t\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16ResponseTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe9\x03\n\x19MethodIntegrationResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x63ontent_handling\x18\x02 \x01(\t\x12j\n\x13response_parameters\x18\x03 \x03(\x0b\x32M.oak9.tython.aws.apigateway.MethodIntegrationResponse.ResponseParametersEntry\x12h\n\x12response_templates\x18\x04 \x03(\x0b\x32L.oak9.tython.aws.apigateway.MethodIntegrationResponse.ResponseTemplatesEntry\x12\x19\n\x11selection_pattern\x18\x05 \x01(\t\x12\x13\n\x0bstatus_code\x18\x06 \x01(\t\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16ResponseTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd4\x05\n\x11MethodIntegration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63\x61\x63he_key_parameters\x18\x02 \x03(\t\x12\x17\n\x0f\x63\x61\x63he_namespace\x18\x03 \x01(\t\x12\x15\n\rconnection_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x05 \x01(\t\x12\x18\n\x10\x63ontent_handling\x18\x06 \x01(\t\x12\x13\n\x0b\x63redentials\x18\x07 \x01(\t\x12\x1f\n\x17integration_http_method\x18\x08 \x01(\t\x12T\n\x15integration_responses\x18\t \x03(\x0b\x32\x35.oak9.tython.aws.apigateway.MethodIntegrationResponse\x12\x1c\n\x14passthrough_behavior\x18\n \x01(\t\x12`\n\x12request_parameters\x18\x0b \x03(\x0b\x32\x44.oak9.tython.aws.apigateway.MethodIntegration.RequestParametersEntry\x12^\n\x11request_templates\x18\x0c \x03(\x0b\x32\x43.oak9.tython.aws.apigateway.MethodIntegration.RequestTemplatesEntry\x12\x19\n\x11timeout_in_millis\x18\r \x01(\x05\x12\x0b\n\x03uri\x18\x0e \x01(\t\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15RequestTemplatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x03\n\x14MethodMethodResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12]\n\x0fresponse_models\x18\x02 \x03(\x0b\x32\x44.oak9.tython.aws.apigateway.MethodMethodResponse.ResponseModelsEntry\x12\x65\n\x13response_parameters\x18\x03 \x03(\x0b\x32H.oak9.tython.aws.apigateway.MethodMethodResponse.ResponseParametersEntry\x12\x13\n\x0bstatus_code\x18\x04 \x01(\t\x1a\x35\n\x13ResponseModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17ResponseParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdb\x05\n\x06Method\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61pi_key_required\x18\x02 \x01(\x08\x12\x1c\n\x14\x61uthorization_scopes\x18\x03 \x03(\t\x12\x1a\n\x12\x61uthorization_type\x18\x04 \x01(\t\x12\x15\n\rauthorizer_id\x18\x05 \x01(\t\x12\x13\n\x0bhttp_method\x18\x06 \x01(\t\x12\x42\n\x0bintegration\x18\x07 \x01(\x0b\x32-.oak9.tython.aws.apigateway.MethodIntegration\x12J\n\x10method_responses\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.apigateway.MethodMethodResponse\x12\x16\n\x0eoperation_name\x18\t \x01(\t\x12M\n\x0erequest_models\x18\n \x03(\x0b\x32\x35.oak9.tython.aws.apigateway.Method.RequestModelsEntry\x12U\n\x12request_parameters\x18\x0b \x03(\x0b\x32\x39.oak9.tython.aws.apigateway.Method.RequestParametersEntry\x12\x1c\n\x14request_validator_id\x18\x0c \x01(\t\x12\x13\n\x0bresource_id\x18\r \x01(\t\x12\x13\n\x0brest_api_id\x18\x0e \x01(\t\x12\x12\n\ndepends_on\x18\x0f \x01(\t\x1a\x34\n\x12RequestModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16RequestParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x01\n\x05Model\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0brest_api_id\x18\x05 \x01(\t\x12=\n\x06schema\x18\x06 \x03(\x0b\x32-.oak9.tython.aws.apigateway.Model.SchemaEntry\x1a-\n\x0bSchemaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x01\n\x10RequestValidator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0brest_api_id\x18\x03 \x01(\t\x12\x1d\n\x15validate_request_body\x18\x04 \x01(\x08\x12#\n\x1bvalidate_request_parameters\x18\x05 \x01(\x08\"~\n\x08Resource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x11\n\tpath_part\x18\x03 \x01(\t\x12\x13\n\x0brest_api_id\x18\x04 \x01(\t\"\x89\x01\n\x11RestApiS3Location\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\r\n\x05\x65_tag\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"\x80\x01\n\x1cRestApiEndpointConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05types\x18\x02 \x03(\t\x12\x18\n\x10vpc_endpoint_ids\x18\x03 \x03(\t\"\xaf\x06\n\x07RestApi\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61pi_key_source_type\x18\x02 \x01(\t\x12\x1a\n\x12\x62inary_media_types\x18\x03 \x03(\t\x12;\n\x04\x62ody\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.apigateway.RestApi.BodyEntry\x12G\n\x10\x62ody_s3_location\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.apigateway.RestApiS3Location\x12\x12\n\nclone_from\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12X\n\x16\x65ndpoint_configuration\x18\x08 \x01(\x0b\x32\x38.oak9.tython.aws.apigateway.RestApiEndpointConfiguration\x12\x18\n\x10\x66\x61il_on_warnings\x18\t \x01(\x08\x12 \n\x18minimum_compression_size\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\x12G\n\nparameters\x18\x0c \x03(\x0b\x32\x33.oak9.tython.aws.apigateway.RestApi.ParametersEntry\x12\x0e\n\x06policy\x18\r \x01(\t\x12;\n\x04tags\x18\x0e \x03(\x0b\x32-.oak9.tython.aws.apigateway.RestApi.TagsEntry\x12$\n\x1c\x64isable_execute_api_endpoint\x18\x0f \x01(\t\x12\x16\n\x0e\x61pi_key_source\x18\x10 \x01(\t\x1a+\n\tBodyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x15StageAccessLogSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x64\x65stination_arn\x18\x02 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\xc3\x02\n\x12StageCanarySetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\x12\x17\n\x0fpercent_traffic\x18\x03 \x01(\x01\x12l\n\x18stage_variable_overrides\x18\x04 \x03(\x0b\x32J.oak9.tython.aws.apigateway.StageCanarySetting.StageVariableOverridesEntry\x12\x17\n\x0fuse_stage_cache\x18\x05 \x01(\x08\x1a=\n\x1bStageVariableOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x02\n\x12StageMethodSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x63\x61\x63he_data_encrypted\x18\x02 \x01(\x08\x12\x1c\n\x14\x63\x61\x63he_ttl_in_seconds\x18\x03 \x01(\x05\x12\x17\n\x0f\x63\x61\x63hing_enabled\x18\x04 \x01(\x08\x12\x1a\n\x12\x64\x61ta_trace_enabled\x18\x05 \x01(\x08\x12\x13\n\x0bhttp_method\x18\x06 \x01(\t\x12\x15\n\rlogging_level\x18\x07 \x01(\t\x12\x17\n\x0fmetrics_enabled\x18\x08 \x01(\x08\x12\x15\n\rresource_path\x18\t \x01(\t\x12\x1e\n\x16throttling_burst_limit\x18\n \x01(\x05\x12\x1d\n\x15throttling_rate_limit\x18\x0b \x01(\x01\"\xe6\x05\n\x05Stage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x12\x61\x63\x63\x65ss_log_setting\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.apigateway.StageAccessLogSetting\x12\x1d\n\x15\x63\x61\x63he_cluster_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12\x63\x61\x63he_cluster_size\x18\x04 \x01(\t\x12\x46\n\x0e\x63\x61nary_setting\x18\x05 \x01(\x0b\x32..oak9.tython.aws.apigateway.StageCanarySetting\x12\x1d\n\x15\x63lient_certificate_id\x18\x06 \x01(\t\x12\x15\n\rdeployment_id\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\x15\x64ocumentation_version\x18\t \x01(\t\x12G\n\x0fmethod_settings\x18\n \x03(\x0b\x32..oak9.tython.aws.apigateway.StageMethodSetting\x12\x13\n\x0brest_api_id\x18\x0b \x01(\t\x12\x12\n\nstage_name\x18\x0c \x01(\t\x12\x39\n\x04tags\x18\r \x03(\x0b\x32+.oak9.tython.aws.apigateway.Stage.TagsEntry\x12\x17\n\x0ftracing_enabled\x18\x0e \x01(\x08\x12\x43\n\tvariables\x18\x0f \x03(\x0b\x32\x30.oak9.tython.aws.apigateway.Stage.VariablesEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x11UsagePlanApiStage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x61pi_id\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12M\n\x08throttle\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.apigateway.UsagePlanApiStage.ThrottleEntry\x1a/\n\rThrottleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x16UsagePlanQuotaSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x0e\n\x06period\x18\x04 \x01(\t\"}\n\x19UsagePlanThrottleSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x62urst_limit\x18\x02 \x01(\x05\x12\x12\n\nrate_limit\x18\x03 \x01(\x01\"\xad\x03\n\tUsagePlan\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x41\n\napi_stages\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.apigateway.UsagePlanApiStage\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x41\n\x05quota\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.apigateway.UsagePlanQuotaSettings\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.apigateway.UsagePlan.TagsEntry\x12G\n\x08throttle\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.apigateway.UsagePlanThrottleSettings\x12\x17\n\x0fusage_plan_name\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x0cUsagePlanKey\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06key_id\x18\x02 \x01(\t\x12\x10\n\x08key_type\x18\x03 \x01(\t\x12\x15\n\rusage_plan_id\x18\x04 \x01(\t\"z\n\x07VpcLink\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0btarget_arns\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_apigateway_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APIKEY_TAGSENTRY._options = None
  _APIKEY_TAGSENTRY._serialized_options = b'8\001'
  _CLIENTCERTIFICATE_TAGSENTRY._options = None
  _CLIENTCERTIFICATE_TAGSENTRY._serialized_options = b'8\001'
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._options = None
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._serialized_options = b'8\001'
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._options = None
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_options = b'8\001'
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._options = None
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._serialized_options = b'8\001'
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._options = None
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._serialized_options = b'8\001'
  _DOMAINNAME_TAGSENTRY._options = None
  _DOMAINNAME_TAGSENTRY._serialized_options = b'8\001'
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._options = None
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._serialized_options = b'8\001'
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._options = None
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_options = b'8\001'
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._options = None
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._options = None
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._serialized_options = b'8\001'
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._options = None
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._serialized_options = b'8\001'
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._options = None
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._serialized_options = b'8\001'
  _METHOD_REQUESTMODELSENTRY._options = None
  _METHOD_REQUESTMODELSENTRY._serialized_options = b'8\001'
  _METHOD_REQUESTPARAMETERSENTRY._options = None
  _METHOD_REQUESTPARAMETERSENTRY._serialized_options = b'8\001'
  _MODEL_SCHEMAENTRY._options = None
  _MODEL_SCHEMAENTRY._serialized_options = b'8\001'
  _RESTAPI_BODYENTRY._options = None
  _RESTAPI_BODYENTRY._serialized_options = b'8\001'
  _RESTAPI_PARAMETERSENTRY._options = None
  _RESTAPI_PARAMETERSENTRY._serialized_options = b'8\001'
  _RESTAPI_TAGSENTRY._options = None
  _RESTAPI_TAGSENTRY._serialized_options = b'8\001'
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._options = None
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_options = b'8\001'
  _STAGE_TAGSENTRY._options = None
  _STAGE_TAGSENTRY._serialized_options = b'8\001'
  _STAGE_VARIABLESENTRY._options = None
  _STAGE_VARIABLESENTRY._serialized_options = b'8\001'
  _USAGEPLANAPISTAGE_THROTTLEENTRY._options = None
  _USAGEPLANAPISTAGE_THROTTLEENTRY._serialized_options = b'8\001'
  _USAGEPLAN_TAGSENTRY._options = None
  _USAGEPLAN_TAGSENTRY._serialized_options = b'8\001'
  _ACCOUNT._serialized_start=77
  _ACCOUNT._serialized_end=173
  _APIGATEWAY._serialized_start=176
  _APIGATEWAY._serialized_end=1030
  _APIKEYSTAGEKEY._serialized_start=1032
  _APIKEYSTAGEKEY._serialized_end=1146
  _APIKEY._serialized_start=1149
  _APIKEY._serialized_end=1501
  _APIKEY_TAGSENTRY._serialized_start=1458
  _APIKEY_TAGSENTRY._serialized_end=1501
  _AUTHORIZER._serialized_start=1504
  _AUTHORIZER._serialized_end=1827
  _BASEPATHMAPPING._serialized_start=1830
  _BASEPATHMAPPING._serialized_end=1980
  _CLIENTCERTIFICATE._serialized_start=1983
  _CLIENTCERTIFICATE._serialized_end=2196
  _CLIENTCERTIFICATE_TAGSENTRY._serialized_start=1458
  _CLIENTCERTIFICATE_TAGSENTRY._serialized_end=1501
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS._serialized_start=2199
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS._serialized_end=2531
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._serialized_start=2470
  _DEPLOYMENTDEPLOYMENTCANARYSETTINGS_STAGEVARIABLEOVERRIDESENTRY._serialized_end=2531
  _DEPLOYMENTACCESSLOGSETTING._serialized_start=2533
  _DEPLOYMENTACCESSLOGSETTING._serialized_end=2659
  _DEPLOYMENTCANARYSETTING._serialized_start=2662
  _DEPLOYMENTCANARYSETTING._serialized_end=2972
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_start=2470
  _DEPLOYMENTCANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_end=2531
  _DEPLOYMENTMETHODSETTING._serialized_start=2975
  _DEPLOYMENTMETHODSETTING._serialized_end=3325
  _DEPLOYMENTSTAGEDESCRIPTION._serialized_start=3328
  _DEPLOYMENTSTAGEDESCRIPTION._serialized_end=4308
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._serialized_start=1458
  _DEPLOYMENTSTAGEDESCRIPTION_TAGSENTRY._serialized_end=1501
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._serialized_start=4260
  _DEPLOYMENTSTAGEDESCRIPTION_VARIABLESENTRY._serialized_end=4308
  _DEPLOYMENT._serialized_start=4311
  _DEPLOYMENT._serialized_end=4625
  _DOCUMENTATIONPARTLOCATION._serialized_start=4628
  _DOCUMENTATIONPARTLOCATION._serialized_end=4777
  _DOCUMENTATIONPART._serialized_start=4780
  _DOCUMENTATIONPART._serialized_end=4970
  _DOCUMENTATIONVERSION._serialized_start=4973
  _DOCUMENTATIONVERSION._serialized_end=5125
  _DOMAINNAMEENDPOINTCONFIGURATION._serialized_start=5127
  _DOMAINNAMEENDPOINTCONFIGURATION._serialized_end=5232
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_start=5235
  _DOMAINNAMEMUTUALTLSAUTHENTICATION._serialized_end=5379
  _DOMAINNAME._serialized_start=5382
  _DOMAINNAME._serialized_end=5856
  _DOMAINNAME_TAGSENTRY._serialized_start=1458
  _DOMAINNAME_TAGSENTRY._serialized_end=1501
  _GATEWAYRESPONSE._serialized_start=5859
  _GATEWAYRESPONSE._serialized_end=6309
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=6194
  _GATEWAYRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=6251
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._serialized_start=6253
  _GATEWAYRESPONSE_RESPONSETEMPLATESENTRY._serialized_end=6309
  _METHODINTEGRATIONRESPONSE._serialized_start=6312
  _METHODINTEGRATIONRESPONSE._serialized_end=6801
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=6194
  _METHODINTEGRATIONRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=6251
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_start=6253
  _METHODINTEGRATIONRESPONSE_RESPONSETEMPLATESENTRY._serialized_end=6309
  _METHODINTEGRATION._serialized_start=6804
  _METHODINTEGRATION._serialized_end=7528
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._serialized_start=7415
  _METHODINTEGRATION_REQUESTPARAMETERSENTRY._serialized_end=7471
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._serialized_start=7473
  _METHODINTEGRATION_REQUESTTEMPLATESENTRY._serialized_end=7528
  _METHODMETHODRESPONSE._serialized_start=7531
  _METHODMETHODRESPONSE._serialized_end=7943
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._serialized_start=7831
  _METHODMETHODRESPONSE_RESPONSEMODELSENTRY._serialized_end=7884
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._serialized_start=6194
  _METHODMETHODRESPONSE_RESPONSEPARAMETERSENTRY._serialized_end=6251
  _METHOD._serialized_start=7946
  _METHOD._serialized_end=8677
  _METHOD_REQUESTMODELSENTRY._serialized_start=8567
  _METHOD_REQUESTMODELSENTRY._serialized_end=8619
  _METHOD_REQUESTPARAMETERSENTRY._serialized_start=7415
  _METHOD_REQUESTPARAMETERSENTRY._serialized_end=7471
  _MODEL._serialized_start=8680
  _MODEL._serialized_end=8932
  _MODEL_SCHEMAENTRY._serialized_start=8887
  _MODEL_SCHEMAENTRY._serialized_end=8932
  _REQUESTVALIDATOR._serialized_start=8935
  _REQUESTVALIDATOR._serialized_end=9113
  _RESOURCE._serialized_start=9115
  _RESOURCE._serialized_end=9241
  _RESTAPIS3LOCATION._serialized_start=9244
  _RESTAPIS3LOCATION._serialized_end=9381
  _RESTAPIENDPOINTCONFIGURATION._serialized_start=9384
  _RESTAPIENDPOINTCONFIGURATION._serialized_end=9512
  _RESTAPI._serialized_start=9515
  _RESTAPI._serialized_end=10330
  _RESTAPI_BODYENTRY._serialized_start=10191
  _RESTAPI_BODYENTRY._serialized_end=10234
  _RESTAPI_PARAMETERSENTRY._serialized_start=10236
  _RESTAPI_PARAMETERSENTRY._serialized_end=10285
  _RESTAPI_TAGSENTRY._serialized_start=1458
  _RESTAPI_TAGSENTRY._serialized_end=1501
  _STAGEACCESSLOGSETTING._serialized_start=10332
  _STAGEACCESSLOGSETTING._serialized_end=10453
  _STAGECANARYSETTING._serialized_start=10456
  _STAGECANARYSETTING._serialized_end=10779
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_start=2470
  _STAGECANARYSETTING_STAGEVARIABLEOVERRIDESENTRY._serialized_end=2531
  _STAGEMETHODSETTING._serialized_start=10782
  _STAGEMETHODSETTING._serialized_end=11127
  _STAGE._serialized_start=11130
  _STAGE._serialized_end=11872
  _STAGE_TAGSENTRY._serialized_start=1458
  _STAGE_TAGSENTRY._serialized_end=1501
  _STAGE_VARIABLESENTRY._serialized_start=4260
  _STAGE_VARIABLESENTRY._serialized_end=4308
  _USAGEPLANAPISTAGE._serialized_start=11875
  _USAGEPLANAPISTAGE._serialized_end=12110
  _USAGEPLANAPISTAGE_THROTTLEENTRY._serialized_start=12063
  _USAGEPLANAPISTAGE_THROTTLEENTRY._serialized_end=12110
  _USAGEPLANQUOTASETTINGS._serialized_start=12113
  _USAGEPLANQUOTASETTINGS._serialized_end=12241
  _USAGEPLANTHROTTLESETTINGS._serialized_start=12243
  _USAGEPLANTHROTTLESETTINGS._serialized_end=12368
  _USAGEPLAN._serialized_start=12371
  _USAGEPLAN._serialized_end=12800
  _USAGEPLAN_TAGSENTRY._serialized_start=1458
  _USAGEPLAN_TAGSENTRY._serialized_end=1501
  _USAGEPLANKEY._serialized_start=12803
  _USAGEPLANKEY._serialized_end=12931
  _VPCLINK._serialized_start=12933
  _VPCLINK._serialized_end=13055
# @@protoc_insertion_point(module_scope)



import os
import unittest
from parameterized import parameterized

from core.bp_metadata_utils.policy import PolicyProvider
from core.bp_metadata_utils.customer_blueprint_repo import CustomerBlueprintRepo
from core.bp_metadata_utils.policy import Policy

this_dir = os.path.dirname(os.path.abspath(__file__))
test_data_path = os.path.join(this_dir, 'testdata', 'oak9')


class TestCustomerBlueprintRepo(unittest.TestCase):

    @parameterized.expand([
        (
                'sparce_implementation_class.py',
                [
                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.AZURE_POLICY,
                        url='https://github.com/Azure/azure-policy/blob/master/built-in-policies/policyDefinitions/Kubernetes/AKS_EncryptionAtHost_Deny.json'),
                ],
        ),
        (
                'well_formed_aws_config_implementation.py',
                [
                    Policy(
                        name='',
                        description='',
                        provider=PolicyProvider.AWS_CONFIG_POLICY,
                        url='https://github.com/awslabs/aws-config-rules/blob/master/python/API_GW_EXECUTION_LOGGING_ENABLED/API_GW_EXECUTION_LOGGING_ENABLED.py'),
                ],
        ),
    ])
    def test_parse_implementations(self, policy_file, want):
        fixture = CustomerBlueprintRepo(token='foo', local_path="/", skip_sync=True)
        policy_path = os.path.join(test_data_path, policy_file)
        got = list(fixture.parse_policy_file(policy_path=policy_path))
        self.assertEqual(want, got)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_folder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_folder.proto\x12\x16oak9.tython.gcp.folder\x1a\x13shared/shared.proto\"O\n\x0f\x46olderXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\xfd\x01\n\x06\x46older\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x17\n\x0flifecycle_state\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06parent\x18\x07 \x01(\t\x12\x39\n\x08timeouts\x18\x08 \x01(\x0b\x32\'.oak9.tython.gcp.folder.FolderXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n-FolderAccessApprovalSettingsXEnrolledServices\x12\x15\n\rcloud_product\x18\x01 \x01(\t\x12\x18\n\x10\x65nrollment_level\x18\x02 \x01(\t\"W\n%FolderAccessApprovalSettingsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd1\x03\n\x1c\x46olderAccessApprovalSettings\x12\x1a\n\x12\x61\x63tive_key_version\x18\x01 \x01(\t\x12\'\n\x1f\x61ncestor_has_active_key_version\x18\x02 \x01(\x08\x12\x19\n\x11\x65nrolled_ancestor\x18\x03 \x01(\x08\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x1b\n\x13invalid_key_version\x18\x06 \x01(\x08\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x1b\n\x13notification_emails\x18\x08 \x03(\t\x12`\n\x11\x65nrolled_services\x18\t \x03(\x0b\x32\x45.oak9.tython.gcp.folder.FolderAccessApprovalSettingsXEnrolledServices\x12O\n\x08timeouts\x18\n \x01(\x0b\x32=.oak9.tython.gcp.folder.FolderAccessApprovalSettingsXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Q\n#FolderIamAuditConfigXAuditLogConfig\x12\x18\n\x10\x65xempted_members\x18\x01 \x03(\t\x12\x10\n\x08log_type\x18\x02 \x01(\t\"\xe1\x01\n\x14\x46olderIamAuditConfig\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x0e\n\x06\x66older\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12U\n\x10\x61udit_log_config\x18\x05 \x03(\x0b\x32;.oak9.tython.gcp.folder.FolderIamAuditConfigXAuditLogConfig\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"T\n\x1a\x46olderIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xdb\x01\n\x10\x46olderIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x0e\n\x06\x66older\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x45\n\tcondition\x18\x06 \x01(\x0b\x32\x32.oak9.tython.gcp.folder.FolderIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"S\n\x19\x46olderIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xd8\x01\n\x0f\x46olderIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x0e\n\x06\x66older\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x44\n\tcondition\x18\x06 \x01(\x0b\x32\x31.oak9.tython.gcp.folder.FolderIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x89\x01\n\x0f\x46olderIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x0e\n\x06\x66older\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\":\n&FolderOrganizationPolicyXBooleanPolicy\x12\x10\n\x08\x65nforced\x18\x01 \x01(\x08\"H\n)FolderOrganizationPolicyXListPolicyXAllow\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"G\n(FolderOrganizationPolicyXListPolicyXDeny\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xfd\x01\n#FolderOrganizationPolicyXListPolicy\x12\x1b\n\x13inherit_from_parent\x18\x01 \x01(\x08\x12\x17\n\x0fsuggested_value\x18\x02 \x01(\t\x12P\n\x05\x61llow\x18\x03 \x01(\x0b\x32\x41.oak9.tython.gcp.folder.FolderOrganizationPolicyXListPolicyXAllow\x12N\n\x04\x64\x65ny\x18\x04 \x01(\x0b\x32@.oak9.tython.gcp.folder.FolderOrganizationPolicyXListPolicyXDeny\"9\n&FolderOrganizationPolicyXRestorePolicy\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\"a\n!FolderOrganizationPolicyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\x86\x04\n\x18\x46olderOrganizationPolicy\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x0e\n\x06\x66older\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x13\n\x0bupdate_time\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\x01\x12V\n\x0e\x62oolean_policy\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.folder.FolderOrganizationPolicyXBooleanPolicy\x12P\n\x0blist_policy\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.folder.FolderOrganizationPolicyXListPolicy\x12V\n\x0erestore_policy\x18\t \x01(\x0b\x32>.oak9.tython.gcp.folder.FolderOrganizationPolicyXRestorePolicy\x12K\n\x08timeouts\x18\n \x01(\x0b\x32\x39.oak9.tython.gcp.folder.FolderOrganizationPolicyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_folder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOLDERXTIMEOUTS._serialized_start=69
  _FOLDERXTIMEOUTS._serialized_end=148
  _FOLDER._serialized_start=151
  _FOLDER._serialized_end=404
  _FOLDERACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_start=406
  _FOLDERACCESSAPPROVALSETTINGSXENROLLEDSERVICES._serialized_end=502
  _FOLDERACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_start=504
  _FOLDERACCESSAPPROVALSETTINGSXTIMEOUTS._serialized_end=591
  _FOLDERACCESSAPPROVALSETTINGS._serialized_start=594
  _FOLDERACCESSAPPROVALSETTINGS._serialized_end=1059
  _FOLDERIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_start=1061
  _FOLDERIAMAUDITCONFIGXAUDITLOGCONFIG._serialized_end=1142
  _FOLDERIAMAUDITCONFIG._serialized_start=1145
  _FOLDERIAMAUDITCONFIG._serialized_end=1370
  _FOLDERIAMBINDINGXCONDITION._serialized_start=1372
  _FOLDERIAMBINDINGXCONDITION._serialized_end=1456
  _FOLDERIAMBINDING._serialized_start=1459
  _FOLDERIAMBINDING._serialized_end=1678
  _FOLDERIAMMEMBERXCONDITION._serialized_start=1680
  _FOLDERIAMMEMBERXCONDITION._serialized_end=1763
  _FOLDERIAMMEMBER._serialized_start=1766
  _FOLDERIAMMEMBER._serialized_end=1982
  _FOLDERIAMPOLICY._serialized_start=1985
  _FOLDERIAMPOLICY._serialized_end=2122
  _FOLDERORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_start=2124
  _FOLDERORGANIZATIONPOLICYXBOOLEANPOLICY._serialized_end=2182
  _FOLDERORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_start=2184
  _FOLDERORGANIZATIONPOLICYXLISTPOLICYXALLOW._serialized_end=2256
  _FOLDERORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_start=2258
  _FOLDERORGANIZATIONPOLICYXLISTPOLICYXDENY._serialized_end=2329
  _FOLDERORGANIZATIONPOLICYXLISTPOLICY._serialized_start=2332
  _FOLDERORGANIZATIONPOLICYXLISTPOLICY._serialized_end=2585
  _FOLDERORGANIZATIONPOLICYXRESTOREPOLICY._serialized_start=2587
  _FOLDERORGANIZATIONPOLICYXRESTOREPOLICY._serialized_end=2644
  _FOLDERORGANIZATIONPOLICYXTIMEOUTS._serialized_start=2646
  _FOLDERORGANIZATIONPOLICYXTIMEOUTS._serialized_end=2743
  _FOLDERORGANIZATIONPOLICY._serialized_start=2746
  _FOLDERORGANIZATIONPOLICY._serialized_end=3264
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DeliveryStreamElasticsearchBufferingHints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    SIZE_IN_MBS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_in_seconds: builtins.int
    size_in_mbs: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_in_seconds: builtins.int = ...,
        size_in_mbs: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["interval_in_seconds", b"interval_in_seconds", "resource_info", b"resource_info", "size_in_mbs", b"size_in_mbs"]) -> None: ...

global___DeliveryStreamElasticsearchBufferingHints = DeliveryStreamElasticsearchBufferingHints

@typing_extensions.final
class DeliveryStreamCloudWatchLoggingOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    LOG_STREAM_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    log_group_name: builtins.str
    log_stream_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        log_group_name: builtins.str = ...,
        log_stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "log_group_name", b"log_group_name", "log_stream_name", b"log_stream_name", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamCloudWatchLoggingOptions = DeliveryStreamCloudWatchLoggingOptions

@typing_extensions.final
class DeliveryStreamProcessorParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETER_NAME_FIELD_NUMBER: builtins.int
    PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    parameter_name: builtins.str
    parameter_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameter_name: builtins.str = ...,
        parameter_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_name", b"parameter_name", "parameter_value", b"parameter_value", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamProcessorParameter = DeliveryStreamProcessorParameter

@typing_extensions.final
class DeliveryStreamProcessor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStreamProcessorParameter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        parameters: collections.abc.Iterable[global___DeliveryStreamProcessorParameter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamProcessor = DeliveryStreamProcessor

@typing_extensions.final
class DeliveryStreamProcessingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    PROCESSORS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def processors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStreamProcessor]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        processors: collections.abc.Iterable[global___DeliveryStreamProcessor] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "processors", b"processors", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamProcessingConfiguration = DeliveryStreamProcessingConfiguration

@typing_extensions.final
class DeliveryStreamElasticsearchRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamElasticsearchRetryOptions = DeliveryStreamElasticsearchRetryOptions

@typing_extensions.final
class DeliveryStreamBufferingHints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INTERVAL_IN_SECONDS_FIELD_NUMBER: builtins.int
    SIZE_IN_MBS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    interval_in_seconds: builtins.int
    size_in_mbs: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        interval_in_seconds: builtins.int = ...,
        size_in_mbs: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["interval_in_seconds", b"interval_in_seconds", "resource_info", b"resource_info", "size_in_mbs", b"size_in_mbs"]) -> None: ...

global___DeliveryStreamBufferingHints = DeliveryStreamBufferingHints

@typing_extensions.final
class DeliveryStreamKMSEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AWS_KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    aws_kms_key_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        aws_kms_key_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_kms_key_arn", b"aws_kms_key_arn", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamKMSEncryptionConfig = DeliveryStreamKMSEncryptionConfig

@typing_extensions.final
class DeliveryStreamEncryptionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    NO_ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def kms_encryption_config(self) -> global___DeliveryStreamKMSEncryptionConfig: ...
    no_encryption_config: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_encryption_config: global___DeliveryStreamKMSEncryptionConfig | None = ...,
        no_encryption_config: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kms_encryption_config", b"kms_encryption_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_encryption_config", b"kms_encryption_config", "no_encryption_config", b"no_encryption_config", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamEncryptionConfiguration = DeliveryStreamEncryptionConfiguration

@typing_extensions.final
class DeliveryStreamS3DestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_ARN_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    COMPRESSION_FORMAT_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    ERROR_OUTPUT_PREFIX_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_arn: builtins.str
    @property
    def buffering_hints(self) -> global___DeliveryStreamBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    compression_format: builtins.str
    @property
    def encryption_configuration(self) -> global___DeliveryStreamEncryptionConfiguration: ...
    error_output_prefix: builtins.str
    prefix: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_arn: builtins.str = ...,
        buffering_hints: global___DeliveryStreamBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        compression_format: builtins.str = ...,
        encryption_configuration: global___DeliveryStreamEncryptionConfiguration | None = ...,
        error_output_prefix: builtins.str = ...,
        prefix: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "encryption_configuration", b"encryption_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_arn", b"bucket_arn", "buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "compression_format", b"compression_format", "encryption_configuration", b"encryption_configuration", "error_output_prefix", b"error_output_prefix", "prefix", b"prefix", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DeliveryStreamS3DestinationConfiguration = DeliveryStreamS3DestinationConfiguration

@typing_extensions.final
class DeliveryStreamVpcConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    role_arn: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        role_arn: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "role_arn", b"role_arn", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___DeliveryStreamVpcConfiguration = DeliveryStreamVpcConfiguration

@typing_extensions.final
class DeliveryStreamElasticsearchDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    DOMAIN_ARN_FIELD_NUMBER: builtins.int
    INDEX_NAME_FIELD_NUMBER: builtins.int
    INDEX_ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    CLUSTER_ENDPOINT_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    VPC_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def buffering_hints(self) -> global___DeliveryStreamElasticsearchBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    domain_arn: builtins.str
    index_name: builtins.str
    index_rotation_period: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamElasticsearchRetryOptions: ...
    role_arn: builtins.str
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    cluster_endpoint: builtins.str
    type_name: builtins.str
    @property
    def vpc_configuration(self) -> global___DeliveryStreamVpcConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        buffering_hints: global___DeliveryStreamElasticsearchBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        domain_arn: builtins.str = ...,
        index_name: builtins.str = ...,
        index_rotation_period: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamElasticsearchRetryOptions | None = ...,
        role_arn: builtins.str = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        cluster_endpoint: builtins.str = ...,
        type_name: builtins.str = ...,
        vpc_configuration: global___DeliveryStreamVpcConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_configuration", b"s3_configuration", "vpc_configuration", b"vpc_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "cluster_endpoint", b"cluster_endpoint", "domain_arn", b"domain_arn", "index_name", b"index_name", "index_rotation_period", b"index_rotation_period", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "role_arn", b"role_arn", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration", "type_name", b"type_name", "vpc_configuration", b"vpc_configuration"]) -> None: ...

global___DeliveryStreamElasticsearchDestinationConfiguration = DeliveryStreamElasticsearchDestinationConfiguration

@typing_extensions.final
class DeliveryStreamHiveJsonSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TIMESTAMP_FORMATS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def timestamp_formats(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        timestamp_formats: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timestamp_formats", b"timestamp_formats"]) -> None: ...

global___DeliveryStreamHiveJsonSerDe = DeliveryStreamHiveJsonSerDe

@typing_extensions.final
class DeliveryStreamOpenXJsonSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ColumnToJsonKeyMappingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CASE_INSENSITIVE_FIELD_NUMBER: builtins.int
    COLUMN_TO_JSON_KEY_MAPPINGS_FIELD_NUMBER: builtins.int
    CONVERT_DOTS_IN_JSON_KEYS_TO_UNDERSCORES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    case_insensitive: builtins.bool
    @property
    def column_to_json_key_mappings(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    convert_dots_in_json_keys_to_underscores: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        case_insensitive: builtins.bool = ...,
        column_to_json_key_mappings: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        convert_dots_in_json_keys_to_underscores: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["case_insensitive", b"case_insensitive", "column_to_json_key_mappings", b"column_to_json_key_mappings", "convert_dots_in_json_keys_to_underscores", b"convert_dots_in_json_keys_to_underscores", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamOpenXJsonSerDe = DeliveryStreamOpenXJsonSerDe

@typing_extensions.final
class DeliveryStreamDeserializer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HIVE_JSON_SER_DE_FIELD_NUMBER: builtins.int
    OPEN_X_JSON_SER_DE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hive_json_ser_de(self) -> global___DeliveryStreamHiveJsonSerDe: ...
    @property
    def open_x_json_ser_de(self) -> global___DeliveryStreamOpenXJsonSerDe: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hive_json_ser_de: global___DeliveryStreamHiveJsonSerDe | None = ...,
        open_x_json_ser_de: global___DeliveryStreamOpenXJsonSerDe | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hive_json_ser_de", b"hive_json_ser_de", "open_x_json_ser_de", b"open_x_json_ser_de", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hive_json_ser_de", b"hive_json_ser_de", "open_x_json_ser_de", b"open_x_json_ser_de", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamDeserializer = DeliveryStreamDeserializer

@typing_extensions.final
class DeliveryStreamInputFormatConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESERIALIZER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def deserializer(self) -> global___DeliveryStreamDeserializer: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deserializer: global___DeliveryStreamDeserializer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deserializer", b"deserializer", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deserializer", b"deserializer", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamInputFormatConfiguration = DeliveryStreamInputFormatConfiguration

@typing_extensions.final
class DeliveryStreamOrcSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_BYTES_FIELD_NUMBER: builtins.int
    BLOOM_FILTER_COLUMNS_FIELD_NUMBER: builtins.int
    BLOOM_FILTER_FALSE_POSITIVE_PROBABILITY_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    DICTIONARY_KEY_THRESHOLD_FIELD_NUMBER: builtins.int
    ENABLE_PADDING_FIELD_NUMBER: builtins.int
    FORMAT_VERSION_FIELD_NUMBER: builtins.int
    PADDING_TOLERANCE_FIELD_NUMBER: builtins.int
    ROW_INDEX_STRIDE_FIELD_NUMBER: builtins.int
    STRIPE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    block_size_bytes: builtins.int
    @property
    def bloom_filter_columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    bloom_filter_false_positive_probability: builtins.float
    compression: builtins.str
    dictionary_key_threshold: builtins.float
    enable_padding: builtins.bool
    format_version: builtins.str
    padding_tolerance: builtins.float
    row_index_stride: builtins.int
    stripe_size_bytes: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        block_size_bytes: builtins.int = ...,
        bloom_filter_columns: collections.abc.Iterable[builtins.str] | None = ...,
        bloom_filter_false_positive_probability: builtins.float = ...,
        compression: builtins.str = ...,
        dictionary_key_threshold: builtins.float = ...,
        enable_padding: builtins.bool = ...,
        format_version: builtins.str = ...,
        padding_tolerance: builtins.float = ...,
        row_index_stride: builtins.int = ...,
        stripe_size_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_size_bytes", b"block_size_bytes", "bloom_filter_columns", b"bloom_filter_columns", "bloom_filter_false_positive_probability", b"bloom_filter_false_positive_probability", "compression", b"compression", "dictionary_key_threshold", b"dictionary_key_threshold", "enable_padding", b"enable_padding", "format_version", b"format_version", "padding_tolerance", b"padding_tolerance", "resource_info", b"resource_info", "row_index_stride", b"row_index_stride", "stripe_size_bytes", b"stripe_size_bytes"]) -> None: ...

global___DeliveryStreamOrcSerDe = DeliveryStreamOrcSerDe

@typing_extensions.final
class DeliveryStreamParquetSerDe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_BYTES_FIELD_NUMBER: builtins.int
    COMPRESSION_FIELD_NUMBER: builtins.int
    ENABLE_DICTIONARY_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_PADDING_BYTES_FIELD_NUMBER: builtins.int
    PAGE_SIZE_BYTES_FIELD_NUMBER: builtins.int
    WRITER_VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    block_size_bytes: builtins.int
    compression: builtins.str
    enable_dictionary_compression: builtins.bool
    max_padding_bytes: builtins.int
    page_size_bytes: builtins.int
    writer_version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        block_size_bytes: builtins.int = ...,
        compression: builtins.str = ...,
        enable_dictionary_compression: builtins.bool = ...,
        max_padding_bytes: builtins.int = ...,
        page_size_bytes: builtins.int = ...,
        writer_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_size_bytes", b"block_size_bytes", "compression", b"compression", "enable_dictionary_compression", b"enable_dictionary_compression", "max_padding_bytes", b"max_padding_bytes", "page_size_bytes", b"page_size_bytes", "resource_info", b"resource_info", "writer_version", b"writer_version"]) -> None: ...

global___DeliveryStreamParquetSerDe = DeliveryStreamParquetSerDe

@typing_extensions.final
class DeliveryStreamSerializer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ORC_SER_DE_FIELD_NUMBER: builtins.int
    PARQUET_SER_DE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def orc_ser_de(self) -> global___DeliveryStreamOrcSerDe: ...
    @property
    def parquet_ser_de(self) -> global___DeliveryStreamParquetSerDe: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        orc_ser_de: global___DeliveryStreamOrcSerDe | None = ...,
        parquet_ser_de: global___DeliveryStreamParquetSerDe | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["orc_ser_de", b"orc_ser_de", "parquet_ser_de", b"parquet_ser_de", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["orc_ser_de", b"orc_ser_de", "parquet_ser_de", b"parquet_ser_de", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamSerializer = DeliveryStreamSerializer

@typing_extensions.final
class DeliveryStreamOutputFormatConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERIALIZER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def serializer(self) -> global___DeliveryStreamSerializer: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        serializer: global___DeliveryStreamSerializer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "serializer", b"serializer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "serializer", b"serializer"]) -> None: ...

global___DeliveryStreamOutputFormatConfiguration = DeliveryStreamOutputFormatConfiguration

@typing_extensions.final
class DeliveryStreamSchemaConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    catalog_id: builtins.str
    database_name: builtins.str
    region: builtins.str
    role_arn: builtins.str
    table_name: builtins.str
    version_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        catalog_id: builtins.str = ...,
        database_name: builtins.str = ...,
        region: builtins.str = ...,
        role_arn: builtins.str = ...,
        table_name: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "database_name", b"database_name", "region", b"region", "resource_info", b"resource_info", "role_arn", b"role_arn", "table_name", b"table_name", "version_id", b"version_id"]) -> None: ...

global___DeliveryStreamSchemaConfiguration = DeliveryStreamSchemaConfiguration

@typing_extensions.final
class DeliveryStreamDataFormatConversionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    INPUT_FORMAT_CONFIGURATION_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_CONFIGURATION_FIELD_NUMBER: builtins.int
    SCHEMA_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def input_format_configuration(self) -> global___DeliveryStreamInputFormatConfiguration: ...
    @property
    def output_format_configuration(self) -> global___DeliveryStreamOutputFormatConfiguration: ...
    @property
    def schema_configuration(self) -> global___DeliveryStreamSchemaConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        input_format_configuration: global___DeliveryStreamInputFormatConfiguration | None = ...,
        output_format_configuration: global___DeliveryStreamOutputFormatConfiguration | None = ...,
        schema_configuration: global___DeliveryStreamSchemaConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input_format_configuration", b"input_format_configuration", "output_format_configuration", b"output_format_configuration", "resource_info", b"resource_info", "schema_configuration", b"schema_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "input_format_configuration", b"input_format_configuration", "output_format_configuration", b"output_format_configuration", "resource_info", b"resource_info", "schema_configuration", b"schema_configuration"]) -> None: ...

global___DeliveryStreamDataFormatConversionConfiguration = DeliveryStreamDataFormatConversionConfiguration

@typing_extensions.final
class DeliveryStreamExtendedS3DestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_ARN_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    COMPRESSION_FORMAT_FIELD_NUMBER: builtins.int
    DATA_FORMAT_CONVERSION_CONFIGURATION_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    ERROR_OUTPUT_PREFIX_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    S3_BACKUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket_arn: builtins.str
    @property
    def buffering_hints(self) -> global___DeliveryStreamBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    compression_format: builtins.str
    @property
    def data_format_conversion_configuration(self) -> global___DeliveryStreamDataFormatConversionConfiguration: ...
    @property
    def encryption_configuration(self) -> global___DeliveryStreamEncryptionConfiguration: ...
    error_output_prefix: builtins.str
    prefix: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    role_arn: builtins.str
    @property
    def s3_backup_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    s3_backup_mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket_arn: builtins.str = ...,
        buffering_hints: global___DeliveryStreamBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        compression_format: builtins.str = ...,
        data_format_conversion_configuration: global___DeliveryStreamDataFormatConversionConfiguration | None = ...,
        encryption_configuration: global___DeliveryStreamEncryptionConfiguration | None = ...,
        error_output_prefix: builtins.str = ...,
        prefix: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        role_arn: builtins.str = ...,
        s3_backup_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        s3_backup_mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "data_format_conversion_configuration", b"data_format_conversion_configuration", "encryption_configuration", b"encryption_configuration", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "s3_backup_configuration", b"s3_backup_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_arn", b"bucket_arn", "buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "compression_format", b"compression_format", "data_format_conversion_configuration", b"data_format_conversion_configuration", "encryption_configuration", b"encryption_configuration", "error_output_prefix", b"error_output_prefix", "prefix", b"prefix", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "role_arn", b"role_arn", "s3_backup_configuration", b"s3_backup_configuration", "s3_backup_mode", b"s3_backup_mode"]) -> None: ...

global___DeliveryStreamExtendedS3DestinationConfiguration = DeliveryStreamExtendedS3DestinationConfiguration

@typing_extensions.final
class DeliveryStreamKinesisStreamSourceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KINESIS_STREAM_ARN_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kinesis_stream_arn: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kinesis_stream_arn: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kinesis_stream_arn", b"kinesis_stream_arn", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DeliveryStreamKinesisStreamSourceConfiguration = DeliveryStreamKinesisStreamSourceConfiguration

@typing_extensions.final
class DeliveryStreamCopyCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COPY_OPTIONS_FIELD_NUMBER: builtins.int
    DATA_TABLE_COLUMNS_FIELD_NUMBER: builtins.int
    DATA_TABLE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    copy_options: builtins.str
    data_table_columns: builtins.str
    data_table_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        copy_options: builtins.str = ...,
        data_table_columns: builtins.str = ...,
        data_table_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["copy_options", b"copy_options", "data_table_columns", b"data_table_columns", "data_table_name", b"data_table_name", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamCopyCommand = DeliveryStreamCopyCommand

@typing_extensions.final
class DeliveryStreamRedshiftRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamRedshiftRetryOptions = DeliveryStreamRedshiftRetryOptions

@typing_extensions.final
class DeliveryStreamRedshiftDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    CLUSTER_J_DB_C_U_R_L_FIELD_NUMBER: builtins.int
    COPY_COMMAND_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    S3_BACKUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    cluster_j_db_c_u_r_l: builtins.str
    @property
    def copy_command(self) -> global___DeliveryStreamCopyCommand: ...
    password: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamRedshiftRetryOptions: ...
    role_arn: builtins.str
    @property
    def s3_backup_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    username: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        cluster_j_db_c_u_r_l: builtins.str = ...,
        copy_command: global___DeliveryStreamCopyCommand | None = ...,
        password: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamRedshiftRetryOptions | None = ...,
        role_arn: builtins.str = ...,
        s3_backup_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "copy_command", b"copy_command", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_backup_configuration", b"s3_backup_configuration", "s3_configuration", b"s3_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "cluster_j_db_c_u_r_l", b"cluster_j_db_c_u_r_l", "copy_command", b"copy_command", "password", b"password", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "role_arn", b"role_arn", "s3_backup_configuration", b"s3_backup_configuration", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration", "username", b"username"]) -> None: ...

global___DeliveryStreamRedshiftDestinationConfiguration = DeliveryStreamRedshiftDestinationConfiguration

@typing_extensions.final
class DeliveryStreamSplunkRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamSplunkRetryOptions = DeliveryStreamSplunkRetryOptions

@typing_extensions.final
class DeliveryStreamSplunkDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    HECACKNOWLEDGMENT_TIMEOUT_IN_SECONDS_FIELD_NUMBER: builtins.int
    HEC_ENDPOINT_FIELD_NUMBER: builtins.int
    HEC_ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    HEC_TOKEN_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    hecacknowledgment_timeout_in_seconds: builtins.int
    hec_endpoint: builtins.str
    hec_endpoint_type: builtins.str
    hec_token: builtins.str
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamSplunkRetryOptions: ...
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        hecacknowledgment_timeout_in_seconds: builtins.int = ...,
        hec_endpoint: builtins.str = ...,
        hec_endpoint_type: builtins.str = ...,
        hec_token: builtins.str = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamSplunkRetryOptions | None = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_configuration", b"s3_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logging_options", b"cloud_watch_logging_options", "hec_endpoint", b"hec_endpoint", "hec_endpoint_type", b"hec_endpoint_type", "hec_token", b"hec_token", "hecacknowledgment_timeout_in_seconds", b"hecacknowledgment_timeout_in_seconds", "processing_configuration", b"processing_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration"]) -> None: ...

global___DeliveryStreamSplunkDestinationConfiguration = DeliveryStreamSplunkDestinationConfiguration

@typing_extensions.final
class DeliveryStreamHttpEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    url: builtins.str
    access_key: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        url: builtins.str = ...,
        access_key: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "name", b"name", "resource_info", b"resource_info", "url", b"url"]) -> None: ...

global___DeliveryStreamHttpEndpointConfiguration = DeliveryStreamHttpEndpointConfiguration

@typing_extensions.final
class DeliveryStreamHttpEndpointCommonAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attribute_name: builtins.str
    attribute_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attribute_name: builtins.str = ...,
        attribute_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_name", b"attribute_name", "attribute_value", b"attribute_value", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamHttpEndpointCommonAttribute = DeliveryStreamHttpEndpointCommonAttribute

@typing_extensions.final
class DeliveryStreamHttpEndpointRequestConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTENT_ENCODING_FIELD_NUMBER: builtins.int
    COMMON_ATTRIBUTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    content_encoding: builtins.str
    @property
    def common_attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStreamHttpEndpointCommonAttribute]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        content_encoding: builtins.str = ...,
        common_attributes: collections.abc.Iterable[global___DeliveryStreamHttpEndpointCommonAttribute] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_attributes", b"common_attributes", "content_encoding", b"content_encoding", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamHttpEndpointRequestConfiguration = DeliveryStreamHttpEndpointRequestConfiguration

@typing_extensions.final
class DeliveryStreamRetryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DURATION_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    duration_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        duration_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration_in_seconds", b"duration_in_seconds", "resource_info", b"resource_info"]) -> None: ...

global___DeliveryStreamRetryOptions = DeliveryStreamRetryOptions

@typing_extensions.final
class DeliveryStreamHttpEndpointDestinationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIGURATION_FIELD_NUMBER: builtins.int
    REQUEST_CONFIGURATION_FIELD_NUMBER: builtins.int
    BUFFERING_HINTS_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGGING_OPTIONS_FIELD_NUMBER: builtins.int
    PROCESSING_CONFIGURATION_FIELD_NUMBER: builtins.int
    RETRY_OPTIONS_FIELD_NUMBER: builtins.int
    S3_BACKUP_MODE_FIELD_NUMBER: builtins.int
    S3_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    role_arn: builtins.str
    @property
    def endpoint_configuration(self) -> global___DeliveryStreamHttpEndpointConfiguration: ...
    @property
    def request_configuration(self) -> global___DeliveryStreamHttpEndpointRequestConfiguration: ...
    @property
    def buffering_hints(self) -> global___DeliveryStreamBufferingHints: ...
    @property
    def cloud_watch_logging_options(self) -> global___DeliveryStreamCloudWatchLoggingOptions: ...
    @property
    def processing_configuration(self) -> global___DeliveryStreamProcessingConfiguration: ...
    @property
    def retry_options(self) -> global___DeliveryStreamRetryOptions: ...
    s3_backup_mode: builtins.str
    @property
    def s3_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        role_arn: builtins.str = ...,
        endpoint_configuration: global___DeliveryStreamHttpEndpointConfiguration | None = ...,
        request_configuration: global___DeliveryStreamHttpEndpointRequestConfiguration | None = ...,
        buffering_hints: global___DeliveryStreamBufferingHints | None = ...,
        cloud_watch_logging_options: global___DeliveryStreamCloudWatchLoggingOptions | None = ...,
        processing_configuration: global___DeliveryStreamProcessingConfiguration | None = ...,
        retry_options: global___DeliveryStreamRetryOptions | None = ...,
        s3_backup_mode: builtins.str = ...,
        s3_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "endpoint_configuration", b"endpoint_configuration", "processing_configuration", b"processing_configuration", "request_configuration", b"request_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "s3_configuration", b"s3_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffering_hints", b"buffering_hints", "cloud_watch_logging_options", b"cloud_watch_logging_options", "endpoint_configuration", b"endpoint_configuration", "processing_configuration", b"processing_configuration", "request_configuration", b"request_configuration", "resource_info", b"resource_info", "retry_options", b"retry_options", "role_arn", b"role_arn", "s3_backup_mode", b"s3_backup_mode", "s3_configuration", b"s3_configuration"]) -> None: ...

global___DeliveryStreamHttpEndpointDestinationConfiguration = DeliveryStreamHttpEndpointDestinationConfiguration

@typing_extensions.final
class DeliveryStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_NAME_FIELD_NUMBER: builtins.int
    DELIVERY_STREAM_TYPE_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    EXTENDED_S3_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    KINESIS_STREAM_SOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    REDSHIFT_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    S3_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    SPLUNK_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    HTTP_ENDPOINT_DESTINATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delivery_stream_name: builtins.str
    delivery_stream_type: builtins.str
    @property
    def elasticsearch_destination_configuration(self) -> global___DeliveryStreamElasticsearchDestinationConfiguration: ...
    @property
    def extended_s3_destination_configuration(self) -> global___DeliveryStreamExtendedS3DestinationConfiguration: ...
    @property
    def kinesis_stream_source_configuration(self) -> global___DeliveryStreamKinesisStreamSourceConfiguration: ...
    @property
    def redshift_destination_configuration(self) -> global___DeliveryStreamRedshiftDestinationConfiguration: ...
    @property
    def s3_destination_configuration(self) -> global___DeliveryStreamS3DestinationConfiguration: ...
    @property
    def splunk_destination_configuration(self) -> global___DeliveryStreamSplunkDestinationConfiguration: ...
    @property
    def http_endpoint_destination_configuration(self) -> global___DeliveryStreamHttpEndpointDestinationConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delivery_stream_name: builtins.str = ...,
        delivery_stream_type: builtins.str = ...,
        elasticsearch_destination_configuration: global___DeliveryStreamElasticsearchDestinationConfiguration | None = ...,
        extended_s3_destination_configuration: global___DeliveryStreamExtendedS3DestinationConfiguration | None = ...,
        kinesis_stream_source_configuration: global___DeliveryStreamKinesisStreamSourceConfiguration | None = ...,
        redshift_destination_configuration: global___DeliveryStreamRedshiftDestinationConfiguration | None = ...,
        s3_destination_configuration: global___DeliveryStreamS3DestinationConfiguration | None = ...,
        splunk_destination_configuration: global___DeliveryStreamSplunkDestinationConfiguration | None = ...,
        http_endpoint_destination_configuration: global___DeliveryStreamHttpEndpointDestinationConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elasticsearch_destination_configuration", b"elasticsearch_destination_configuration", "extended_s3_destination_configuration", b"extended_s3_destination_configuration", "http_endpoint_destination_configuration", b"http_endpoint_destination_configuration", "kinesis_stream_source_configuration", b"kinesis_stream_source_configuration", "redshift_destination_configuration", b"redshift_destination_configuration", "resource_info", b"resource_info", "s3_destination_configuration", b"s3_destination_configuration", "splunk_destination_configuration", b"splunk_destination_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream_name", b"delivery_stream_name", "delivery_stream_type", b"delivery_stream_type", "elasticsearch_destination_configuration", b"elasticsearch_destination_configuration", "extended_s3_destination_configuration", b"extended_s3_destination_configuration", "http_endpoint_destination_configuration", b"http_endpoint_destination_configuration", "kinesis_stream_source_configuration", b"kinesis_stream_source_configuration", "redshift_destination_configuration", b"redshift_destination_configuration", "resource_info", b"resource_info", "s3_destination_configuration", b"s3_destination_configuration", "splunk_destination_configuration", b"splunk_destination_configuration"]) -> None: ...

global___DeliveryStream = DeliveryStream

@typing_extensions.final
class KinesisFirehose(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_STREAM_FIELD_NUMBER: builtins.int
    @property
    def delivery_stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryStream]: ...
    def __init__(
        self,
        *,
        delivery_stream: collections.abc.Iterable[global___DeliveryStream] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_stream", b"delivery_stream"]) -> None: ...

global___KinesisFirehose = KinesisFirehose



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2
import kubernetes.kubernetes_io.k8s.api.certificates.v1_pb2
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.api.networking.v1_pb2
import kubernetes.kubernetes_io.k8s.api.node.v1_pb2
import kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Kubernetes_NonNamespaced(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_STATUS_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    NODE_FIELD_NUMBER: builtins.int
    PERSISTENT_VOLUME_FIELD_NUMBER: builtins.int
    CERTIFICATE_SIGNING_REQUEST_FIELD_NUMBER: builtins.int
    MUTATING_WEBHOOK_CONFIGURATION_FIELD_NUMBER: builtins.int
    VALIDATING_WEBHOOK_CONFIGURATION_FIELD_NUMBER: builtins.int
    INGRESS_CLASS_FIELD_NUMBER: builtins.int
    RUNTIME_CLASS_FIELD_NUMBER: builtins.int
    CLUSTER_ROLE_BINDING_FIELD_NUMBER: builtins.int
    CLUSTER_ROLE_FIELD_NUMBER: builtins.int
    @property
    def component_status(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ComponentStatus]: ...
    @property
    def namespace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Namespace]: ...
    @property
    def node(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Node]: ...
    @property
    def persistent_volume(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolume]: ...
    @property
    def certificate_signing_request(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.certificates.v1_pb2.CertificateSigningRequest]: ...
    @property
    def mutating_webhook_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2.MutatingWebhookConfiguration]: ...
    @property
    def validating_webhook_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2.ValidatingWebhookConfiguration]: ...
    @property
    def ingress_class(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.IngressClass]: ...
    @property
    def runtime_class(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.node.v1_pb2.RuntimeClass]: ...
    @property
    def cluster_role_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.ClusterRoleBinding]: ...
    @property
    def cluster_role(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.ClusterRole]: ...
    def __init__(
        self,
        *,
        component_status: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ComponentStatus] | None = ...,
        namespace: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Namespace] | None = ...,
        node: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Node] | None = ...,
        persistent_volume: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolume] | None = ...,
        certificate_signing_request: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.certificates.v1_pb2.CertificateSigningRequest] | None = ...,
        mutating_webhook_configuration: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2.MutatingWebhookConfiguration] | None = ...,
        validating_webhook_configuration: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.admissionregistration.v1_pb2.ValidatingWebhookConfiguration] | None = ...,
        ingress_class: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.networking.v1_pb2.IngressClass] | None = ...,
        runtime_class: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.node.v1_pb2.RuntimeClass] | None = ...,
        cluster_role_binding: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.ClusterRoleBinding] | None = ...,
        cluster_role: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.rbac.v1_pb2.ClusterRole] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_signing_request", b"certificate_signing_request", "cluster_role", b"cluster_role", "cluster_role_binding", b"cluster_role_binding", "component_status", b"component_status", "ingress_class", b"ingress_class", "mutating_webhook_configuration", b"mutating_webhook_configuration", "namespace", b"namespace", "node", b"node", "persistent_volume", b"persistent_volume", "runtime_class", b"runtime_class", "validating_webhook_configuration", b"validating_webhook_configuration"]) -> None: ...

global___Kubernetes_NonNamespaced = Kubernetes_NonNamespaced
